==> haskell-dyre-0.9.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dyre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dyre
version:              0.9.2
visibility:           public
id:                   dyre-0.9.2-EyIDJ6YBEgJJNRqTesC8bs
key:                  dyre-0.9.2-EyIDJ6YBEgJJNRqTesC8bs
license:              BSD-3-Clause
copyright:            (c) 2011-2023 Will Donnelly, Fraser Tweedale
maintainer:           Fraser Tweedale <frase@frase.id.au>
author:               Will Donnelly
stability:            beta
homepage:             http://github.com/willdonnelly/dyre
synopsis:             Dynamic reconfiguration in Haskell
description:
    Dyre implements dynamic reconfiguration facilities after the
    style of Xmonad. Dyre aims to be as simple as possible without
    sacrificing features, and places an emphasis on simplicity of
    integration with an application.
    A full introduction with a complete example project can be found
    in the documentation for '\''Config.Dyre'\''

category:             Development, Configuration
abi:                  c5327187aa93b9a52f5ff267cde7d321
exposed:              True
exposed-modules:
    Config.Dyre Config.Dyre.Compat Config.Dyre.Compile
    Config.Dyre.Options Config.Dyre.Params Config.Dyre.Paths
    Config.Dyre.Relaunch

import-dirs:          /usr/lib/ghc-9.0.2/site-local/dyre-0.9.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dyre-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/dyre-0.9.2
hs-libraries:         HSdyre-0.9.2-EyIDJ6YBEgJJNRqTesC8bs
depends:
    base-4.15.1.0 binary-0.8.8.0 directory-1.3.6.2
    executable-path-0.0.3.1-AWiOm0iMK03AvVPZm1VkN7 filepath-1.4.2.1
    io-storage-0.3-9azuhge7ZFZCNn897h31hW process-1.6.13.2 time-1.9.3
    unix-2.7.2.2 xdg-basedir-0.2.2-DeGg1ryr7ndmwRYCQYweT

haddock-interfaces:   /usr/share/doc/haskell-dyre/html/dyre.haddock
haddock-html:         /usr/share/doc/haskell-dyre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dyre-0.9.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dyre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dyre
version:              0.9.2
visibility:           public
id:                   dyre-0.9.2-5abLnFQgVLs9P4QvCpgWpr
key:                  dyre-0.9.2-5abLnFQgVLs9P4QvCpgWpr
license:              BSD-3-Clause
copyright:            (c) 2011-2023 Will Donnelly, Fraser Tweedale
maintainer:           Fraser Tweedale <frase@frase.id.au>
author:               Will Donnelly
stability:            beta
homepage:             http://github.com/willdonnelly/dyre
synopsis:             Dynamic reconfiguration in Haskell
description:
    Dyre implements dynamic reconfiguration facilities after the
    style of Xmonad. Dyre aims to be as simple as possible without
    sacrificing features, and places an emphasis on simplicity of
    integration with an application.
    A full introduction with a complete example project can be found
    in the documentation for '\''Config.Dyre'\''

category:             Development, Configuration
abi:                  c702447b2a8420d7cfca65256e5d5955
exposed:              True
exposed-modules:
    Config.Dyre Config.Dyre.Compat Config.Dyre.Compile
    Config.Dyre.Options Config.Dyre.Params Config.Dyre.Paths
    Config.Dyre.Relaunch

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dyre-0.9.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dyre-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dyre
hs-libraries:         HSdyre-0.9.2-5abLnFQgVLs9P4QvCpgWpr
depends:
    base-4.16.4.0 binary-0.8.9.0 directory-1.3.6.2
    executable-path-0.0.3.1-K1paw4SCDvS8wuNA9ltaVf filepath-1.4.2.2
    io-storage-0.3-AK0jChG7QLrF2LpXoYjRhr process-1.6.16.0
    time-1.11.1.1 unix-2.7.2.2 xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83

haddock-interfaces:   /usr/share/doc/haskell-dyre/html/dyre.haddock
haddock-html:         /usr/share/doc/haskell-dyre/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
